# Multi-view Broad Learning Systerm (MVBLS)


[![Python Versions](https://img.shields.io/pypi/pyversions/MVBLS.svg?logo=python&logoColor=white)](https://pypi.org/project/MVBLS)
[![Documentation Status](https://readthedocs.org/projects/mvbls/badge/?version=latest)](https://mvbls.readthedocs.io/)
[![PyPI Version](https://img.shields.io/pypi/v/MVBLS.svg?logo=pypi&logoColor=white)](https://pypi.org/project/MVBLS)
[![License](https://img.shields.io/github/license/zhaochangming/MVBLS.svg)](https://github.com/zhaochangming/MVBLS/blob/main/LICENSE)

**Multi-view broad learning systerm (MVBLS)** [1] is a multi-view  framework that bases on BLS [2]. It is designed to be efficient with the following advantages:

- Support of classification and regression in supervised multi-view or multi-modal learning.
- Support of classification and regression in semi-supervised multi-view or multi-modal learning [3].
- Support of two or more views or modals.

## Get Started and Documentation

Our primary documentation is at https://mvbls.readthedocs.io/ and is generated from this repository. If you are new to MVBLS, follow [the installation instructions](https://mvbls.readthedocs.io/en/latest/Python-Intro.html) on that site. The preferred way to install MVBLS is via pip from [Pypi](https://pypi.org/project/MVBLS).

Next you may want to read:
- [**APIs & Parameters**](https://mvbls.readthedocs.io/en/latest/MVBLS.html) is an exhaustive list of customization you can make.
- [**Parameters Tuning**](https://mvbls.readthedocs.io/en/latest/Parameters-Tuning.html) is an exhaustive list of customization you can make.
- [**Examples**](https://mvbls.readthedocs.io/en/latest/Python-Examples.html) showing command line usage of common tasks.

## References

[1] Z. Shi, X. Chen, C. Zhao, H. He, V. Stuphorn and D. Wu, "Multi-view broad learning system for primate oculomotor decision decoding," in IEEE Trans. on Neural Systems and Rehabilitation Engineering, vol. 28, no. 9, pp. 1908-1920, 2020.

[2] C. L. P. Chen and Z. Liu, "Broad learning system: An effective and efficient incremental learning system without the need for deep architecture," in IEEE Trans. on Neural Networks and Learning Systems, vol. 29, no. 1, pp. 10-24, 2018.

[3] T. Qiu, X. Liu, X. Zhou, W. Qu, Z. Ning and C. L. P. Chen, "An adaptive social spammer detection model with semi-supervised broad learning," in IEEE Trans. on Knowledge and Data Engineering, doi: 10.1109/TKDE.2020.3047857.